<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Brian2694\Toastr\Facades\Toastr;
use App\Models\Customer; 
use App\Models\Bill; 
use DB;

class CustomerController extends Controller
{
    //
    public function index()
    {
        $customers = Customer::all();

        return view('customer.index', compact('customers')); 
    }

    public function store(Request $request)
    {
        $request->validate([
            'first_name'   => 'required|string',
            'last_name'    => 'required|string',
            'phone'        => 'required'
        ]);
       
        DB::beginTransaction();
        try{

            $customer = new Customer;
            $customer->first_name = $request->first_name;
            $customer->last_name  = $request->last_name;
            $customer->address    = $request->address;
            $customer->phone      = $request->phone;
            
            $customer->save();

            DB::commit();
            Toastr::success('Client ajouté avec succée :)','Success');
            return redirect()->route('customer');
           
        }catch(\Exception $e){
            DB::rollback();
            Toastr::error('Opération echouée :)','Error');
            return redirect()->back();
        }
    }

    public function update(Request $request)
    {
        DB::beginTransaction();
        
        try {

            $update = [
                'last_name'     => $request->last_name_update,
                'first_name'    => $request->first_name_update,
                'phone'         => $request->phone_update, 
                'address'       => $request->address_update 
            ];

            Customer::where('id',$request->id_customer_update)->update($update);
            DB::commit();

            Toastr::success('Mise à jour des informations du client sont effectués avec succée :)','Succé');
            return redirect()->back();
        } catch(\Exception $e) {
            DB::rollback();
            Toastr::error('Opération échouée :)','Erreur');
            return redirect()->back(); 
        }
    }
        
    public function delete(Request $request)
    {
        DB::beginTransaction(); 

        try{
            $bill = Bill::where('customer_id', '=', $request->id_customer_delete)->get(); 
            
            if($bill->count() == 0)
            {
                Toastr::info('Il y\'a des factures lié à ce client, veuillez les supprimer d\'abord :)','Info');
                return redirect()->back();
            }
           
            Customer::destroy($request->id_customer_delete);
            
            Toastr::success('Client supprimé avec succée :)','Success');

            return redirect()->back();
        
        }catch(\Exception $e){
            DB::rollback();
            Toastr::error('Echec de l\'opération :)','Error');
            return redirect()->back();
        }
    }
    
}
